searchNodes=[{"doc":"Documentation for Beetle module. This is the main API for the Beetle rate-limiter. This module assumes a backend pool has been started, most likely by the Beetle application.","ref":"Beetle.html","title":"Beetle","type":"module"},{"doc":"Check if the action you wish to perform is within the bounds of the rate-limit. Args: id : String name of the bucket. Usually the bucket name is comprised of some fixed prefix, with some dynamic string appended, such as an IP address or user id. scale_ms : Integer indicating size of bucket in milliseconds limit : Integer maximum count of actions within the bucket Returns either {:allow, count} , {:deny, limit} or {:error, reason} Example: user_id = 42076 case check_rate ( &quot;file_upload: \#{ user_id } &quot; , 60_000 , 5 ) do { :allow , _count } -&gt; # do the file upload { :deny , _limit } -&gt; # render an error page or something end","ref":"Beetle.html#check_rate/3","title":"Beetle.check_rate/3","type":"function"},{"doc":"Same as check_rate/3, but allows specifying a backend","ref":"Beetle.html#check_rate/4","title":"Beetle.check_rate/4","type":"function"},{"doc":"Same as check_rate/3, but allows the increment number to be specified. This is useful for limiting apis which have some idea of 'cost', where the cost of each hit can be specified.","ref":"Beetle.html#check_rate_inc/4","title":"Beetle.check_rate_inc/4","type":"function"},{"doc":"Same as check_rate_inc/4, but allows specifying a backend.","ref":"Beetle.html#check_rate_inc/5","title":"Beetle.check_rate_inc/5","type":"function"},{"doc":"Delete all buckets belonging to the provided id, including the current one. Effectively resets the rate-limit for the id. Arguments: id : String name of the bucket Returns either {:ok, count} where count is the number of buckets deleted, or {:error, reason} . Example: user_id = 2406 { :ok , _count } = delete_buckets ( &quot;file_uploads: \#{ user_id } &quot; )","ref":"Beetle.html#delete_buckets/1","title":"Beetle.delete_buckets/1","type":"function"},{"doc":"Same as delete_buckets/1, but allows specifying a backend","ref":"Beetle.html#delete_buckets/2","title":"Beetle.delete_buckets/2","type":"function"},{"doc":"Inspect bucket to get count, count_remaining, ms_to_next_bucket, created_at, updated_at. This function is free of side-effects and should be called with the same arguments you would use for check_rate if you intended to increment and check the bucket counter. Arguments: id : String name of the bucket. Usually the bucket name is comprised of some fixed prefix,with some dynamic string appended, such as an IP address or user id. scale_ms : Integer indicating size of bucket in milliseconds limit : Integer maximum count of actions within the bucket Returns either {:ok, {count, count_remaining, ms_to_next_bucket, created_at, updated_at} , or {:error, reason} . Example: inspect_bucket ( &quot;file_upload:2042&quot; , 60_000 , 5 ) { :ok , { 1 , 2499 , 29381612 , 1450281014468 , 1450281014468 } }","ref":"Beetle.html#inspect_bucket/3","title":"Beetle.inspect_bucket/3","type":"function"},{"doc":"Same as inspect_bucket/3, but allows specifying a backend","ref":"Beetle.html#inspect_bucket/4","title":"Beetle.inspect_bucket/4","type":"function"},{"doc":"Make a rate-checker function, with the given id prefix, scale_ms and limit. Arguments: id_prefix : String prefix to the id scale_ms : Integer indicating size of bucket in milliseconds limit : Integer maximum count of actions within the bucket Returns a function which accepts an id suffix, which will be combined with the id_prefix . Calling this returned function is equivalent to: Beetle.check_rate(&quot;\#{id_prefix}\#{id}&quot;, scale_ms, limit) Example: chat_rate_limiter = make_rate_checker ( &quot;send_chat_message:&quot; , 60_000 , 20 ) user_id = 203517 case chat_rate_limiter . ( user_id ) do { :allow , _count } -&gt; # allow chat message { :deny , _limit } -&gt; # deny end","ref":"Beetle.html#make_rate_checker/3","title":"Beetle.make_rate_checker/3","type":"function"},{"doc":"","ref":"Beetle.html#make_rate_checker/4","title":"Beetle.make_rate_checker/4","type":"function"},{"doc":"The backend Behaviour module","ref":"Beetle.Backend.html","title":"Beetle.Backend","type":"behaviour"},{"doc":"","ref":"Beetle.Backend.html#c:count_hit/3","title":"Beetle.Backend.count_hit/3","type":"callback"},{"doc":"","ref":"Beetle.Backend.html#c:count_hit/4","title":"Beetle.Backend.count_hit/4","type":"callback"},{"doc":"","ref":"Beetle.Backend.html#c:delete_buckets/2","title":"Beetle.Backend.delete_buckets/2","type":"callback"},{"doc":"","ref":"Beetle.Backend.html#c:get_bucket/2","title":"Beetle.Backend.get_bucket/2","type":"callback"},{"doc":"","ref":"Beetle.Backend.html#t:bucket_info/0","title":"Beetle.Backend.bucket_info/0","type":"type"},{"doc":"","ref":"Beetle.Backend.html#t:bucket_key/0","title":"Beetle.Backend.bucket_key/0","type":"type"},{"doc":"An ETS backend for Beetle Note: This backend is suitable for development, testing, and small single-node deployments, but should not be used for production workloads. The public API of this module is used by Beetle to store information about rate-limit 'buckets'. A bucket is identified by a key , which is a tuple {bucket_number, id} . The essential schema of a bucket is: {key, count, created_at, updated_at} , although backends are free to store and retrieve this data in whichever way they wish. Use start or start_link to start the server: { :ok , pid } = Beetle.Backend.ETS . start_link ( args ) args is a keyword list: ets_table_name : (atom) table name to use, defaults to :beetle_ets_buckets expiry_ms : (integer) time in ms before a bucket is auto-deleted, should be larger than the expected largest size/duration of a bucket cleanup_interval_ms : (integer) time between cleanup runs, Example: Beetle.Backend.ETS . start_link ( expiry_ms : 1000 * 60 * 60 , cleanup_interval_ms : 1000 * 60 * 10 )","ref":"Beetle.Backend.ETS.html","title":"Beetle.Backend.ETS","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Beetle.Backend.ETS.html#child_spec/1","title":"Beetle.Backend.ETS.child_spec/1","type":"function"},{"doc":"Record a hit in the bucket identified by key","ref":"Beetle.Backend.ETS.html#count_hit/3","title":"Beetle.Backend.ETS.count_hit/3","type":"function"},{"doc":"Record a hit in the bucket identified by key , with a custom increment","ref":"Beetle.Backend.ETS.html#count_hit/4","title":"Beetle.Backend.ETS.count_hit/4","type":"function"},{"doc":"Delete all buckets associated with id .","ref":"Beetle.Backend.ETS.html#delete_buckets/2","title":"Beetle.Backend.ETS.delete_buckets/2","type":"function"},{"doc":"Retrieve information about the bucket identified by key","ref":"Beetle.Backend.ETS.html#get_bucket/2","title":"Beetle.Backend.ETS.get_bucket/2","type":"function"},{"doc":"Callback implementation for GenServer.init/1 .","ref":"Beetle.Backend.ETS.html#init/1","title":"Beetle.Backend.ETS.init/1","type":"function"},{"doc":"","ref":"Beetle.Backend.ETS.html#start/0","title":"Beetle.Backend.ETS.start/0","type":"function"},{"doc":"","ref":"Beetle.Backend.ETS.html#start/1","title":"Beetle.Backend.ETS.start/1","type":"function"},{"doc":"","ref":"Beetle.Backend.ETS.html#start_link/0","title":"Beetle.Backend.ETS.start_link/0","type":"function"},{"doc":"","ref":"Beetle.Backend.ETS.html#start_link/1","title":"Beetle.Backend.ETS.start_link/1","type":"function"},{"doc":"","ref":"Beetle.Backend.ETS.html#stop/0","title":"Beetle.Backend.ETS.stop/0","type":"function"},{"doc":"","ref":"Beetle.Backend.ETS.html#t:bucket_info/0","title":"Beetle.Backend.ETS.bucket_info/0","type":"type"},{"doc":"","ref":"Beetle.Backend.ETS.html#t:bucket_key/0","title":"Beetle.Backend.ETS.bucket_key/0","type":"type"},{"doc":"Top-level Supervisor for the Beetle application. Starts a set of poolboy pools based on provided configuration, which are latter called to by the Beetle module. See the Application module for configuration examples.","ref":"Beetle.Supervisor.html","title":"Beetle.Supervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Beetle.Supervisor.html#child_spec/1","title":"Beetle.Supervisor.child_spec/1","type":"function"},{"doc":"Callback implementation for Supervisor.init/1 .","ref":"Beetle.Supervisor.html#init/1","title":"Beetle.Supervisor.init/1","type":"function"},{"doc":"","ref":"Beetle.Supervisor.html#start_link/2","title":"Beetle.Supervisor.start_link/2","type":"function"}]